"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.socialUrl = exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _Atoms = require("../../Atoms");

var _modal = require("./modal.styles");

var _ModalBottom = _interopRequireDefault(require("./ModalBottom"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const socialUrl = {
  FACEBOOK: 'https://www.facebook.com/sharer/sharer.php?',
  TWITTER: 'https://twitter.com/intent/tweet?',
  WHATSAPP: 'https://wa.me?'
};
exports.socialUrl = socialUrl;

async function openUrl(url) {
  return new Promise((resolve, reject) => {
    _reactNative.Linking.canOpenURL(url).then(supported => {
      if (supported) {
        _reactNative.Linking.openURL(url).then(data => {
          return resolve(true);
        }).catch(() => {
          return reject(false);
        });
      }
    }).catch(err => {
      throw reject(err);
    });
  });
}

async function handlePostToFaceBook(shareLink, postContent) {
  let facebookParameters = [];
  facebookParameters.push('u=' + encodeURI(shareLink));
  facebookParameters.push('quote=' + encodeURI(postContent));
  const url = socialUrl.FACEBOOK + facebookParameters.join('&');
  const openned = await openUrl(url);
  return openned;
}

async function handleTwit(shareLink, tweetContent) {
  let twitterParameters = [];
  twitterParameters.push('url=' + encodeURI(shareLink));
  twitterParameters.push('text=' + encodeURI(tweetContent));
  const url = socialUrl.TWITTER + twitterParameters.join('&');
  const openned = await openUrl(url);
  return openned;
}

async function shareToWa(shareLink, msg) {
  let url = `${socialUrl.WHATSAPP}text=${msg}`;
  const openned = await openUrl(url);
  return openned;
}

async function onShare(content) {
  try {
    const result = await _reactNative.Share.share({
      message: content
    });

    if (result.action === _reactNative.Share.sharedAction) {
      if (result.activityType) {// shared with activity type of result.activityType
      } else {// shared
      }
    } else if (result.action === _reactNative.Share.dismissedAction) {// dismissed
    }
  } catch (error) {
    // alert(error.message);
    console.log('error', error);
  }
}

const ShareModal = /*#__PURE__*/(0, _react.forwardRef)((_ref, ref) => {
  let { ...props
  } = _ref;
  const SocialsApp = [{
    id: 0,
    name: 'Facebook',
    icon: require('../../../assets/icons/socials/fb.png'),
    handleShare: (url, content) => handlePostToFaceBook(url, content)
  }, {
    id: 1,
    name: 'Twitter',
    icon: require('../../../assets/icons/socials/twitter.png'),
    handleShare: (url, content) => handleTwit(url, content)
  }, {
    id: 2,
    name: 'Whatsapp',
    icon: require('../../../assets/icons/socials/wa.png'),
    handleShare: (url, content) => shareToWa(url, content)
  }, {
    id: 3,
    name: 'Lainnya',
    icon: require('../../../assets/icons/socials/more.png'),
    handleShare: (url, content) => onShare(content)
  }];
  const [showModalShare, setShowModalShare] = (0, _react.useState)({
    title: 'Bagikan Produk Melalui',
    isVisible: false,
    sharedUrl: 'https://hidoop.link/0pwGb6mnOo6',
    content: ''
  });
  (0, _react.useImperativeHandle)(ref, () => ({
    _showModal: data => showModal(data),
    _closeModal: () => closeModal()
  }));
  return /*#__PURE__*/_react.default.createElement(_ModalBottom.default, {
    title: showModalShare === null || showModalShare === void 0 ? void 0 : showModalShare.title,
    isVisible: showModalShare === null || showModalShare === void 0 ? void 0 : showModalShare.isVisible,
    onBackdropPress: closeModal,
    onBackButtonPress: closeModal,
    body: /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: _modal.styles.modalBody
    }, SocialsApp.map(i => {
      const _handleShare = async () => {
        i.handleShare(showModalShare === null || showModalShare === void 0 ? void 0 : showModalShare.sharedUrl, showModalShare === null || showModalShare === void 0 ? void 0 : showModalShare.content);
      };

      return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
        key: i.id,
        onPress: _handleShare,
        style: _modal.styles.itemSocial
      }, /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
        source: i.icon,
        style: _modal.styles.imgSocial
      }), /*#__PURE__*/_react.default.createElement(_Atoms.Text, {
        text: i === null || i === void 0 ? void 0 : i.name,
        size: "small"
      }));
    }))
  });

  function showModal() {
    let data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    setShowModalShare({ ...showModalShare,
      ...data,
      isVisible: true
    });
  }

  function closeModal() {
    setShowModalShare({
      isVisible: false,
      title: 'Bagikan Produk Melalui',
      url: '',
      content: ''
    });
  }
});
var _default = ShareModal;
exports.default = _default;
//# sourceMappingURL=ShareModal.js.map