function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import moment from 'moment-timezone';
import 'moment/locale/id';
import propTypes from 'prop-types';
import React, { forwardRef, useEffect, useImperativeHandle, useState } from 'react';
import { ActivityIndicator, Pressable, TextInput, View } from 'react-native';
import DateTimePickerModal from 'react-native-modal-datetime-picker';
import { colors, Fonts, width } from '../../../constant/theme';
import { Icon, Text } from '../../Atoms';
import { styles } from './input.style';
const inputType = ['email', 'phonenumber', 'datepicker', 'dropdown', 'default'];
const StackedLabelInput = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    label,
    labelSize,
    labelColor,
    value,
    keyboardType,
    containerStyle,
    inputStyle,
    invalidInput,
    invalidMsg,
    optional,
    required,
    secureTextEntry,
    type,
    disabled,
    right,
    placeholder,
    onDateChange,
    onPress,
    isLoading,
    onClearText,
    extraLabel,
    _child,
    ...props
  } = _ref;
  useImperativeHandle(ref, () => ({
    showDatePicker: _showDatePicker,
    closeDatePicker: _closeDatePicker
  }));
  const [showEntry, setShowEntry] = useState(secureTextEntry);
  const [showPicker, setShowPicker] = useState(false);
  const [tempSelectDate, setTempSelectDate] = useState({
    date: '',
    formattedDate: ''
  });
  const [invalidEmail, setInvalidEmail] = useState(false);
  useEffect(() => {
    if (type === inputType[2]) {
      if (value) {
        const initDate = moment(value, 'DD-MM-YYYY').toDate();
        setTempSelectDate({
          date: initDate,
          formattedDate: moment(initDate).format('DD-MM-YYYY')
        });
      } else {
        setTempSelectDate({
          date: new Date(),
          formattedDate: 'DD-MM-YYYY'
        });
      }
    }
  }, [value, type]);

  function _showDatePicker() {
    setShowPicker(true);
  }

  function _closeDatePicker() {
    setShowPicker(false);
  }

  const RenderChildren = () => {
    let Child = null;
    let Main = /*#__PURE__*/React.createElement(TextInput, _extends({}, props, {
      placeholder: placeholder,
      style: [Fonts.regular, Fonts.small, styles.formInput, {
        width: right ? '90%' : '100%'
      }, inputStyle],
      value: value,
      secureTextEntry: showEntry,
      keyboardType: keyboardType,
      underlineColorAndroid: "transparent"
    }));

    if (onClearText) {
      Child = /*#__PURE__*/React.createElement(Pressable, {
        disabled: disabled,
        onPress: onClearText,
        style: {
          width: width * 0.07
        }
      }, /*#__PURE__*/React.createElement(Icon, {
        name: 'close',
        color: invalidInput ? colors.grey.grey9 : colors.grey.grey8,
        size: 15
      }));
    }

    if (type === inputType[0]) {
      //email
      let widthInput = '100%';

      if (right) {
        widthInput = '90%';
      } else if (_child) {
        widthInput = '70%';
      }

      if (value.length < 2 && !invalidInput) {
        Child = null;
      } else {
        Main = /*#__PURE__*/React.createElement(TextInput, _extends({}, props, {
          style: [Fonts.regular, Fonts.small, styles.formInput, {
            width: widthInput
          }, inputStyle],
          placeholder: placeholder,
          value: value,
          secureTextEntry: showEntry,
          keyboardType: "email-address",
          autoCapitalize: "none",
          autoCorrect: false,
          underlineColorAndroid: "transparent"
        }));
        Child = _child ? _child : null;
      }
    } else if (type === inputType[1]) {
      //phonenumber
      Main = /*#__PURE__*/React.createElement(TextInput, _extends({}, props, {
        placeholder: placeholder,
        style: [Fonts.regular, Fonts.small, styles.formInput, {
          width: right ? '90%' : '100%'
        }, inputStyle],
        value: value,
        secureTextEntry: showEntry,
        keyboardType: "phone-pad",
        underlineColorAndroid: "transparent"
      }));
    } else if (type === inputType[2]) {
      //datepicker
      let inputValue = '';

      if (value) {
        inputValue = value;
      } else if (!value) {
        if (tempSelectDate.formattedDate) {
          inputValue = tempSelectDate.formattedDate;
        } else {
          inputValue = placeholder;
        }
      }

      Main = /*#__PURE__*/React.createElement(Pressable, {
        onPress: _showDatePicker
      }, /*#__PURE__*/React.createElement(Text, {
        text: inputValue,
        color: tempSelectDate.formattedDate ? colors.grey.black : colors.grey.grey3,
        textStyle: [styles.formInput]
      }));
      Child = /*#__PURE__*/React.createElement(Pressable, {
        disabled: disabled,
        onPress: _showDatePicker,
        style: {
          width: width * 0.07
        }
      }, /*#__PURE__*/React.createElement(Icon, {
        name: 'calendar',
        color: colors.grey.grey2,
        size: 16
      }));
    } else if (type === inputType[3]) {
      //dropdown
      Main = /*#__PURE__*/React.createElement(Text, {
        text: value ? value : placeholder,
        color: value ? colors.grey.black : colors.grey.grey3,
        textStyle: [styles.formInput]
      });
      Child = /*#__PURE__*/React.createElement(Pressable, {
        disabled: disabled,
        style: {
          width: width * 0.07
        }
      }, /*#__PURE__*/React.createElement(Icon, {
        name: 'back_down-frame',
        color: colors.grey.grey2,
        size: 15
      }));
    }

    return /*#__PURE__*/React.createElement(View, {
      style: styles.content
    }, Main, isLoading ? /*#__PURE__*/React.createElement(ActivityIndicator, {
      size: 'small',
      color: colors.primary
    }) : Child);
  };

  return /*#__PURE__*/React.createElement(View, {
    style: [styles.container, containerStyle]
  }, label ? /*#__PURE__*/React.createElement(View, {
    style: styles.labelWrapper
  }, /*#__PURE__*/React.createElement(Text, {
    text: label,
    size: labelSize ? labelSize : 'large' //   variant="bold"
    ,
    textStyle: {
      color: labelColor ? labelColor : colors.grey.grey8
    }
  }), required ? /*#__PURE__*/React.createElement(Text, {
    text: "*",
    color: colors.primary
  }) : null, optional ? /*#__PURE__*/React.createElement(Text, {
    text: "(Opsional)",
    textStyle: {
      marginLeft: width * 0.02
    }
  }) : null, extraLabel !== null && extraLabel !== void 0 && extraLabel.text ? /*#__PURE__*/React.createElement(Text, {
    text: extraLabel === null || extraLabel === void 0 ? void 0 : extraLabel.text,
    color: extraLabel === null || extraLabel === void 0 ? void 0 : extraLabel.color,
    size: extraLabel === null || extraLabel === void 0 ? void 0 : extraLabel.size,
    textStyle: {
      marginLeft: width * 0.02
    }
  }) : null) : null, /*#__PURE__*/React.createElement(Pressable, {
    disabled: isLoading,
    onPress: onPress,
    style: styles.formInputContainer
  }, RenderChildren(), /*#__PURE__*/React.createElement(TextInput, _extends({}, props, {
    clearButtonMode: "always",
    placeholder: placeholder,
    style: [Fonts.regular, Fonts.medium, styles.formInput, {
      width: right ? '90%' : '100%'
    }, inputStyle],
    value: value,
    secureTextEntry: showEntry,
    keyboardType: keyboardType,
    underlineColorAndroid: "transparent"
  }))), invalidInput && type !== 'email' && /*#__PURE__*/React.createElement(Text, {
    text: invalidMsg ? invalidMsg : `${label} tidak boleh kosong`,
    size: "small",
    color: colors.error
  }), /*#__PURE__*/React.createElement(DateTimePickerModal, {
    isVisible: showPicker,
    date: tempSelectDate.date ? new Date(tempSelectDate.date) : new Date(),
    mode: "date",
    maximumDate: new Date(),
    onConfirm: date => {
      setShowPicker(false);
      onDateChange(moment(date).format('DD-MM-YYYY'));
      setTempSelectDate({
        date: date,
        formattedDate: moment(date).format('DD-MM-YYYY')
      });
    },
    onCancel: () => {
      setShowPicker(false);
    }
  }));
});
StackedLabelInput.propTypes = {
  label: propTypes.string,
  containerStyle: propTypes.oneOfType([propTypes.object, propTypes.array]),
  type: propTypes.oneOf(inputType),
  inputStyle: propTypes.oneOfType([propTypes.object, propTypes.array]),
  invalidInput: propTypes.bool,
  extraLabel: propTypes.object,
  _child: propTypes.node
};
StackedLabelInput.defaultProps = {
  containerStyle: {},
  inputStyle: {},
  keyboardType: 'default',
  value: '',
  invalidInput: false,
  type: 'default',
  extraLabel: {
    text: '',
    color: colors.grey.black,
    size: 'medium'
  },
  _child: null
};
export default StackedLabelInput;
//# sourceMappingURL=StackedLabelInput.js.map