import React, { useEffect, useState } from 'react';
import { TouchableOpacity, View } from 'react-native';
import { colors } from '../../../constant/theme';
import { Icon } from '../../Atoms';
import { TextInputIcon } from '../Input';
import Header from './Header';
import { styles } from './header.style';

const HeaderSearch = ({
  noShadow,
  style,
  onPress,
  onChangeVal,
  iconColor,
  placeholder = 'Search here',
  onClearText,
  ...props
}) => {
  const [searchVal, setSearchVal] = useState('');

  useEffect(() => {
    onChangeVal ? onChangeVal(searchVal) : null;
  }, [searchVal]);

  return (
    <Header noShadow={noShadow} style={style}>
      <View style={styles.headerSearch}>
        <TouchableOpacity onPress={onPress}>
          <Icon
            name="arrow-left"
            color={iconColor ? iconColor : colors.grey.black}
            size={30}
          />
        </TouchableOpacity>
        <TextInputIcon
          style={styles.searchInput}
          placeholder={placeholder}
          onChangeText={(val) => setSearchVal(val)}
          value={searchVal}
          onClearText={onClearText}
          {...props}
        />
      </View>
    </Header>
  );
};

export default HeaderSearch;
